# SOARS paddle temperature monitor

Polls and logs temperature data from [PicoTech TC-08](https://www.picotech.com/data-logger/tc-08/thermocouple-data-logger) USB temperature probe interface. Data is stored in a local InfluxDB instance and can be viewed via a compatible visualization web ui such as Chronograf.

## Requirements

- Tested on Raspberry Pi running Raspbian Lite OS (32-bit) "Bullseye" (Debain 11) Kernel Version 5.15
- Python3.6 or later
  - [influxdb-python](https://github.com/influxdata/influxdb-python)
  - numpy (dependency of picosdk)
- [picosdk](https://www.picotech.com/downloads/linux) (installs [picosdk-python-wrappers](https://github.com/picotech/picosdk-python-wrappers/tree/master/usbtc08Examples))
- InfluxDB 1.x (tested on 1.8.10)
- Chronograf (web ui and visualization for InfluxDB)
- Kapacitor (optional alerting system)

# Setup

## Raspberry Pi setup

- [Raspberry Pi installation guide](https://www.raspberrypi.com/documentation/computers/getting-started.html#using-raspberry-pi-imager)
- Run `apt get update`

## wifi

Getting onto a WPA2 enterprise network took jumping through some hoops, I think this is the minimum required config:
1. Add config to `/etc/wpa_supplicant.conf` and `/etc/dhcpcd.conf` [instructions](https://iceburn.medium.com/raspberry-pi-connected-to-wifi-of-wpa2-enterprise-ddd5a40c0b07)
2. You can store the password as a hash, see [here](https://forums.raspberrypi.com/viewtopic.php?t=261526)

## Python setup

1. Make sure pip is installed `sudo apt install python3-pip`
2. install influxdb python module

## picosdk installation

[picotech website](https://www.picotech.com/downloads/linux)
1. install picoscope following Ubuntu 20.04 LTS instructions. This will also install python bindings.
2. also install usbtc08-dev package `sudo apt install usbtc08-dev`

## InfluxDB

[InfluxDB](https://docs.influxdata.com/influxdb/v1.8/) is a timeseries database. There are two major versions, 1.x and 2.x. This software assumes a 1.x installation (there exists a different python library to interact with influx 2.x, and 2.x might come bundled with different UI and alerting tools than Chronograf and Kapacitor).

### Installation
There is a repository you can add to apt to install the latest 1.x build with service definitions:
[Instructions](https://pimylifeup.com/raspberry-pi-influxdb/)

### configuration
Defalut config should work, config file lives at `/etc/influxdb/influxdb.conf`

TODO: set up password authentication

## Chronograf

[Chronograf](https://docs.influxdata.com/chronograf/v1.9/) is a web UI to create dashboards based on influxDB data.

### Installation

Assuming you added the influxdata repository during InfluxDB installation, Chronograf can be installed by just `sudo apt install chronograf`

### Web UI

Navigate to http://[pi's ip address]:8888/

On first time login, you will be prompted to connect the influxdb instance (use default settings)

## Kapacitor

[Kapacitor](https://docs.influxdata.com/kapacitor/v1.6/) is an alerting system. It can be configured to sent email or other alerts dependent on data updates in influxdb.

### Installation

Download .deb installer for arm from the [downloads page](https://portal.influxdata.com/downloads/) (scroll down to "Are you interested in InfluxDB 1.x Open Source?")
`wget https://dl.influxdata.com/kapacitor/releases/kapacitor_1.6.5-1_arm64.deb`
`sudo dpkg -i kapacitor_1.6.5-1_arm64.deb`

## Install monitor service
A [systemd](https://wiki.debian.org/systemd#systemd_-_system_and_service_manager) service definition is provided. To configure and install it:
1. Edit `tc08-monitor.service` to refer to the username (if different from `pi`) and the path of the cloned `soars-paddle-temperature` repo
2. copy `tc08-monitor.service` to `/etc/systemd/system/.`
3. `sudo systemctl daemon-reload`
4. `sudo systemctl enable tc08-monitor`
5. `sudo systemctl start tc08-monitor`
The service is now installed and enabled to start on system boot.

### useful commands

Interact with the [systemd](https://wiki.debian.org/systemd#systemd_-_system_and_service_manager) service manager with `systemctl` command as root. Common commands are `start`, `stop`, and `status` (e.g. `sudo systemctly status tc08-monitor`). You can prevent a service from auto-starting by disabling it with the `disable` command, or re-enabling it with `enable`.

Service debugging output is sent to the systemd journal, which can be read with `journalctl` (e.g. `sudo journalctl -u tc08-monitor`)