import datetime
import influxdb


class InfluxDBBridge():
    def __init__(self):
        # todo make this stuff configurable
        self.host = 'localhost'
        self.port = 8086
        self.username = None
        self.password = None
        self.dbname = 'paddle'

    def connect(self):
        # create and open client
        self.client = influxdb.InfluxDBClient(
            self.host,
            self.port,
            self.username,
            self.password,
            self.dbname
        )
        # try to create db just in case
        try:
            self.client.create_database(self.dbname)
        except influxdb.client.InfluxDBClientError:
            # db already exists, proceed
            pass

    def make_json(self, channel, location, temperature, time_ms, overflow):
        json_body = [
            {
                'measurement': 'paddle_bearings',
                'tags': {
                    'channel': channel,
                    'location': location
                },
                'time': time_ms,
                'fields': {
                    'temperature': temperature,
                    'overflow': overflow
                }
            }
        ]
        return json_body

    def commit_point(self, channel, location, temperature, time_ms, overflow):
        json_body = self.make_json(
            channel, location, temperature, time_ms, overflow)
        self.client.write_points(json_body, time_precision='ms')

    def print_point(self, channel, temperature, time_ms):
        print(f'{time_ms}: [{channel}] {temperature} \u00B0C')
